#
# spec file for package python-python-box
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# python_requires='>=3.6'
%define skip_python2 1
Name:           python-python-box
Version:        4.2.2
Release:        lp152.1.1
Summary:        Advanced Python dictionaries with dot notation access
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/cdgriffith/Box
Source:         https://github.com/cdgriffith/Box/archive/%{version}.tar.gz
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pathlib}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module ruamel.yaml}
BuildRequires:  %{python_module testsuite}
BuildRequires:  %{python_module toml}
# /SECTION
Requires:       python-ruamel.yaml
Requires:       python-toml
%python_subpackages

%description
Advanced Python dictionaries with dot notation access

%prep
%setup -q -n Box-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH='.'
%pytest_arch

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/*

%changelog
* Fri Mar 20 2020 pgajdos@suse.com
- version update to 4.2.2
  Version 4.2.2
  - ------------
  * Fixing `default_box` doesn't first look for safe attributes before falling back to default (thanks to Pymancer)
  * Changing from TravisCI to Github Actions
  Version 4.2.1
  - ------------
  * Fixing uncaught print statement (thanks to Bruno Rocha)
  * Fixing old references to `box_it_up` in the documentation
  Version 4.2.0
  - ------------
  * Adding optimizations for speed ups to creation and inserts
  * Adding internal record of safe attributes for faster lookups, increases memory footprint for speed (thanks to Jonas Irgens Kylling)
  * Adding all additional methods specific to `Box` as protected keys
  * Fixing `merge_update` from incorrectly calling `__setattr__` which was causing a huge slowdown (thanks to Jonas Irgens Kylling)
  * Fixing `copy` and `__copy__` not copying box options
  Version 4.1.0
  - ------------
  * Adding support for list traversal with `box_dots` (thanks to Lei)
  * Adding `BoxWarning` class to allow for the clean suppression of warnings
  * Fixing default_box_attr to accept items that evaluate to `None` (thanks to Wenbo Zhao and Yordan Ivanov)
  * Fixing `BoxList` to properly send internal box options down into new lists
  * Fixing issues with conversion and camel killer boxes not being set properly on insert
  * Changing default_box to set objects in box on lookup
  * Changing `camel_killer` to convert items on insert, which will change the keys when converted back to dict unlike before
  * Fallback to `PyYAML` if `ruamel.yaml` is not detected (thanks to wim glenn)
  * Removing official support for `pypy` as it's pickling behavior is not the same as CPython
  * Removing internal __box_heritage as it was no longer needed due to behavior update
  Version 4.0.4
  - ------------
  * Fixing `get` to return None when not using default box (thanks to Jeremiah Lowin)
  * Fixing non-string keys breaking when box_dots is enabled (thanks to Marcelo Huerta)
  Version 4.0.2
  - ------------
  * Fixing converters to properly pass through new box arguments (thanks to Marcelo Huerta)
  Version 4.0.1
  - ------------
  * Fixing setup.py for release
  * Fixing documentation link
  Version 4.0.0
  - ------------
  * Adding support for retrieving items via dot notation in keys
  * Adding `box_from_file` helper function
  * Adding merge_update that acts like previous Box magic update
  * Adding support to `+` boxes together
  * Adding default_box now can support expanding on `None` placeholders (thanks to Harun Tuncay and Jeremiah Lowin)
  * Adding ability to recast specified fields (thanks to Steven McGrath)
  * Adding to_csv and from_csv capability for BoxList objects (thanks to Jiuli Gao)
  * Changing layout of project to be more object specific
  * Changing update to act like normal dict update
  * Changing to 120 line character limit
  * Changing how `safe_attr` handles unsafe characters
  * Changing all exceptions to be bases of BoxError so can always be caught with that base exception
  * Changing delete to also access converted keys (thanks to iordanivanov)
  * Changing from `PyYAML` to `ruamel.yaml` as default yaml import, aka yaml version default is 1.2 instead of 1.1
  * Removing `ordered_box` as Python 3.6+ is ordered by default
  * Removing `BoxObject` in favor of it being another module
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.4.3:
  * Fixing propagation of box options when adding a new list via setdefault (thanks to Stretch)
  * Fixing update does not keep box_intact_types (thanks to pwwang)
  * Fixing update to operate the same way as a normal dictionary (thanks to Craig Quiter)
  * Fixing deepcopy not copying box options (thanks to Nikolay Stanishev)
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.4.2:
  * Adding license, changes and authors files to source distribution
* Wed Jun 19 2019 Thomas Bechtold <tbechtold@suse.com>
- Initial packaging (version 3.4.1)
